Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MessageCreate ¶
type MessageCreate struct {
api.Message
GuildID api.Snowflake `json:"guild_id,omitempty"`
Member api.GuildMember `json:"member,omitempty"`
Mentions []api.User `json:"mentions"`
}
MessageCreate - Sent when a message is created. The inner payload is a message object with the following extra fields
type MessageDelete ¶
type MessageDelete struct {
ID api.Snowflake `json:"id"`
ChannelID api.Snowflake `json:"channel_id"`
GuildID api.Snowflake `json:"guild_id,omitempty"`
}
MessageDelete - Sent when a message is deleted.
type MessageDeleteBulk ¶
type MessageDeleteBulk struct {
IDS []api.Snowflake `json:"ids"`
ChannelID api.Snowflake `json:"channel_id"`
GuildID api.Snowflake `json:"guild_id,omitempty"`
}
MessageDeleteBulk - Sent when multiple messages are deleted at once.
type MessageReactionAdd ¶
type MessageReactionAdd struct {
UserID api.Snowflake `json:"user_id"`
ChannelID api.Snowflake `json:"channel_id"`
MessageID api.Snowflake `json:"message_id"`
GuildID api.Snowflake `json:"guild_id,omitempty"`
Member api.GuildMember `json:"member,omitempty"`
Emoji api.Emoji `json:"emoji"`
}
MessageReactionAdd - Sent when a user adds a reaction to a message.
type MessageReactionRemove ¶
type MessageReactionRemove struct {
UserID api.Snowflake `json:"user_id"`
ChannelID api.Snowflake `json:"channel_id"`
MessageID api.Snowflake `json:"message_id"`
GuildID api.Snowflake `json:"guild_id,omitempty"`
Emoji api.Emoji `json:"emoji"`
}
MessageReactionRemove - Sent when a user removes a reaction from a message.
type MessageReactionRemoveAll ¶
type MessageReactionRemoveAll struct {
ChannelID api.Snowflake `json:"channel_id"`
MessageID api.Snowflake `json:"message_id"`
GuildID api.Snowflake `json:"guild_id,omitempty"`
}
MessageReactionRemoveAll - Sent when a user explicitly removes all reactions from a message.
type MessageReactionRemoveEmoji ¶
type MessageReactionRemoveEmoji struct {
ChannelID api.Snowflake `json:"channel_id"`
GuildID api.Snowflake `json:"guild_id,omitempty"`
MessageID api.Snowflake `json:"message_id"`
Emoji api.Emoji `json:"emoji"`
}
MessageReactionRemoveEmoji - Sent when a bot removes all instances of a given emoji from the reactions of a message.
type MessageUpdate ¶
type MessageUpdate MessageCreate
MessageUpdate - Sent when a message is updated. The inner payload is a message object with the same extra fields as MessageCreate.